@@ -15,13 +15,14 @@ from inforion.excelexport import *
 from inforion.helper.filehandling import *
 from inforion.ionapi.controller import *
 from inforion.ionapi.model import *
+import inforion.ln as lni
 
 import logging
 import os.path
 import os
 
 import logging
-from logger import get_logger
+#from logger import get_logger
 
 from inforion.datacatalog.datacatalog import (
     post_datacatalog_object,
@@ -176,6 +177,18 @@ def transform(mappingfile, mainsheet, inputfile, outputfile):
     inputdata = pd.read_excel(inputfile)
     return infor.main_transformation(mappingfile, mainsheet, inputdata, outputfile)
 
+@click.command(name="merge", help="section to do the file merging")
+@click.option("--mergesheet1", "-i", help="Please define the first merge file")
+@click.option("--mergesheet2", "-n", help="Please define the second merge file")
+@click.option("--mergeoutput", "-o", help="Please define the output file for merge")
+@click.option("--mergecol", "-c", help="Please define the column criteria for merge")
+@click.option("--mergetype", "-t", help="Please define the merging type")
+def merge(mergesheet1, mergesheet2, mergeoutput, mergecol, mergetype="outer"):
+    print(mergetype)
+    sheet1 = pd.read_excel(mergesheet1)
+    sheet2 = pd.read_excel(mergesheet2)
+    return infor.main_merge(sheet1, sheet2, mergeoutput, mergecol, mergetype)
+
 
 @main.group(name="catalog")
 def catalog():
@@ -352,9 +365,29 @@ def check_token(url, ionfile):
     inforlogin.login()
 
 
+@main.group(name="ln")
+def ln():
+    """Commands related to Export Data from LN."""
+    pass
+
+
+@ln.command(name="ExportData", help="Export Data")
+@click.option("--url", "-u", help="URL to local ION")
+@click.option("--ionfile", "-i", help="Please define the ionfile file")
+@click.option("--company", "-c", help="Company for which we need to export")
+@click.option("--service_name", "-s", help="Service name. e.g. BusinessPartner, SalesOrder")
+@click.option("--outputfile", "-o", help="File as Output File")
+def export_data(url, ionfile, company, service_name, outputfile):
+    """Exports business partner to an Excel file"""
+
+    inforlogin.load_config(ionfile)
+    token = inforlogin.login()['access_token']
+    lni.export_data(url, token, company, service_name, outputfile)
+
 main.add_command(load)
 main.add_command(transform)
 main.add_command(extract)
+main.add_command(merge)
 main.add_command(check)
 
 if __name__ == "__main__":
