@@ -17,6 +17,8 @@ from requests_oauthlib import OAuth2Session
 from requests.auth import HTTPBasicAuth
 from oauthlib.oauth2 import BackendApplicationClient
 
+import logging
+#from logger import get_logger
 
 from requests.adapters import HTTPAdapter
 from requests.packages.urllib3.util.retry import Retry
@@ -61,7 +63,7 @@ def execute(
     methode = methode.split(",")
     methode_count = len(methode)
 
-    print("Number of rows " + str(total_rows))
+    logging.info("Number of rows " + str(total_rows))
 
     with progressbar.ProgressBar(max_value=total_rows) as bar:
         for index, row in df.iterrows():
@@ -131,7 +133,7 @@ def executeSnd(
     total_rows = df.shape[0]
     total_rows = int(total_rows)
 
-    print("Number of rows " + str(total_rows))
+    logging.info("Number of rows " + str(total_rows))
 
     a = []
     with progressbar.ProgressBar(max_value=total_rows) as bar:
@@ -161,17 +163,13 @@ def executeSnd(
     df = df.astype(str)
 
     if outputfile is not None:
-        print("Save to file: " + outputfile)
-        filehandling.savetodisk(outputfile, df)
-
+        logging.info('Save to file: ' + outputfile)
+        filehandling.savetodisk(outputfile,df)
+    
     return df
 
 
-def executeAsyncSnd(
-    url, headers, program, methode, dataframe, _outputfile=None, start=0, end=None
-):
-
-    print("Still in Beta")
+    logging.info("Still in Beta")
 
     df = dataframe
 
@@ -189,7 +187,7 @@ def executeAsyncSnd(
     total_rows = df.shape[0]
     total_rows = int(total_rows)
 
-    print("Number of rows " + str(total_rows))
+    logging.info("Number of rows " + str(total_rows))
 
     a = []
     with progressbar.ProgressBar(max_value=total_rows) as bar:
@@ -213,9 +211,11 @@ def executeAsyncSnd(
         index = index + 1
         # df,data,chunk = saveresults(r,df,methode,index,chunk)
 
-    print(r)
+  
 
-    """
+    logging.info(r)
+
+  
 
     df = df.replace(np.nan, '', regex=True)
     df = df.astype(str)
@@ -226,7 +226,7 @@ def executeAsyncSnd(
     
     return df
 
-    """
+   
 
 
 def getSuccessGraphDataframe(df):
